@@ -31,7 +31,7 @@ package Apache2::ImageRenderFilter;
   # 
 
   use vars qw($VERSION);
-  $VERSION= "2.03";
+  $VERSION= "2.05";
   my %Capability;
   my %Array_fb;
   my %Array_id;
@@ -159,7 +159,7 @@ sub handler    {
       my $location;
       my $width_toSearch;
       my $type_redirect="internal";
-      my $return_value;
+      my $return_value=Apache2::Const::DECLINED;
 	  my $dummy="";
 	  my $variabile2="";
 	  my %ArrayCapFound;
@@ -171,6 +171,7 @@ sub handler    {
       my $width=1000;
       my $height=1000;
       my $image2="";
+      
       if ($f->r->pnotes('width')) {      
       	$width=$f->r->pnotes('width')
       }
@@ -273,19 +274,27 @@ Apache2::ImageRenderFilter - used to resize images on the fly to adapt to the sc
 =head1 COREQUISITES
 
 Apache2::RequestRec
+
 Apache2::RequestUtil
+
 Apache2::SubRequest
+
 Apache2::Log
+
 Apache2::Filter
+
 APR::Table
+
 LWP::Simple
+
 Image::Resize
+
 Apache2::Const
-IO::Uncompress::Unzip
+
 File::Copy;
 
 
-=head1 SYNOPSIS
+=head1 DESCRIPTION
 
 This module have the scope to manage with WURFLFilter.pm module the images for mobile devices. 
 
@@ -293,31 +302,41 @@ For more details: http://www.idelfuschini.it/apache-mobile-filter-v2x.html
 
 An example of how to set the httpd.conf is below:
 
-PerlSetEnv MOBILE_HOME server_root/MobileFilter
+=over 4
 
-#This indicate to the filter where put the transformated images (cache directory) this directory must be writeable
-PerlSetEnv ResizeImageDirectory /transform
+=item C<PerlSetEnv MOBILE_HOME server_root/MobileFilter>
 
-PerlModule Apache2::WURFLFilter
-PerlTransHandler +Apache2::WURFLFilter
+This indicate to the filter where put the transformated images (cache directory) this directory must be writeable
 
-#This is indicate to the filter were are stored the high definition images
-<Location /mobile/*>
-    SetHandler modperl
-    PerlInputFilterHandler Apache2::ImageRenderFilter 
-</Location> 
+=item C<PerlSetEnv ResizeImageDirectory /transform>
 
+=item C<PerlModule Apache2::WURFLFilter>
+=item C<PerlTransHandler +Apache2::WURFLFilter>
 
+This is indicate to the filter were are stored the high definition images
+
+=item C<<Location /mobile/*>>
+
+=item C<    SetHandler modperl>
+
+=item C<    PerlInputFilterHandler Apache2::ImageRenderFilter >
+
+=item C<</Location>> 
+
+=back
 
 NOTE: this software need wurfl.xml you can download it directly from this site: http://wurfl.sourceforge.net or you can set the filter to download it directly.
 
-=head1 DOCUMENTATION & DEMO
+=head1 SEE ALSO
 
 For more details: http://www.idelfuschini.it/apache-mobile-filter-v2x.html
 
+Mobile Demo page of the filter: http://apachemobilefilter.nogoogle.it (thanks Ivan alias sigmund)
+
 Demo page of the filter: http://apachemobilefilter.nogoogle.it/php_test.php (thanks Ivan alias sigmund)
 
 =head1 AUTHOR
-Idel Fuschini (idel.fuschini [at] gmail [dot] com
+
+Idel Fuschini (idel.fuschini [at] gmail [dot] com)
 
 =cut
