@@ -30,7 +30,7 @@ package Apache2::WURFLFilter;
   # 
 
   use vars qw($VERSION);
-  $VERSION= "2.04";
+  $VERSION= "2.05";
   my %Capability;
   my %Array_fb;
   my %Array_id;
@@ -54,18 +54,17 @@ package Apache2::WURFLFilter;
   my $downloadwurflurl="false";
   my $convertimage="false";
   my $resizeimagedirectory="";
-  my $downloadzipfile="true";
   my $repasshanlder=0;
   my $globalpassvariable="";
   my $log4wurfl="";
   my $loadwebpatch="false";
-  my $dirwebpatch="";
   my $patchwurflnetdownload="false"; 
   my $patchwurflurl="";
   my $redirecttranscoder="true";
   my $redirecttranscoderurl="none";
   my $listall="false";
   my $cookiecachesystem="false";
+  my $WURFLVersion="unknown";
   
   $ImageType{'png'}="png";
   $ImageType{'gif'}="gif";
@@ -127,10 +126,6 @@ sub loadConfigFile {
 				$downloadwurflurl=$ENV{DownloadWurflURL};
 				printLog("DownloadWurflURL is: $downloadwurflurl");
 			 }	
-	      	 if ($ENV{DownloadZipFile}) {
-				$downloadzipfile=$ENV{DownloadZipFile};
-				printLog("DownloadZipFile is: $downloadzipfile");
-			 }	
 	      	 if ($ENV{CapabilityList}) {
 				my @dummycapability = split(/,/, $ENV{CapabilityList});
 				foreach $dummy (@dummycapability) {
@@ -146,10 +141,6 @@ sub loadConfigFile {
 				$loadwebpatch=$ENV{LoadWebPatch};
 				printLog("LoadWebPatch is: $loadwebpatch");
 			 }	
-	      	 if ($ENV{DirWebPatch}) {
-				$dirwebpatch=$ENV{DirWebPatch};
-				printLog("DirWebpatch is: $dirwebpatch");
-			 }	
 	      	 if ($ENV{PatchWurflNetDownload}) {
 				$patchwurflnetdownload=$ENV{PatchWurflNetDownload};
 				printLog("PatchWurflNetDownload is: $patchwurflnetdownload");
@@ -167,33 +158,27 @@ sub loadConfigFile {
 	    printLog("Finish loading  parameter");
 	    printLog("----------------------------------");
 	    if ($wurflnetdownload eq "true") {
-	        printLog("Start downloading  WURFL.xml from $downloadwurflurl");
-	        my $content = get ($downloadwurflurl);
-	        printLog("Finish downloading  WURFL.xml");
-	        if ($content eq "") {
+	        printLog("Start process downloading  WURFL.xml from $downloadwurflurl");
+	        my $data = Data();
+	        printLog ("Test the  URL");
+	        my ($content_type, $document_length, $modified_time, $expires, $server) = head($downloadwurflurl);
+	        if ($content_type eq "") {
    		        printLog("Couldn't get $downloadwurflurl.");
 		   		ModPerl::Util::exit();
+	        } else {
+	            printLog("The URL is correct");
+	            printLog("The size of document wurf file: $document_length bytes");	       
 	        }
 	        
-	        if ($downloadzipfile eq 'true') {
-	              printLog("Uncompress File start");
+	        if ($content_type eq 'application/zip') {
+	              printLog("The file is a zip file.");
+	              printLog ("Start downloading");
 				  my @dummypairs = split(/\//, $downloadwurflurl);
 				  my ($ext_zip) = $downloadwurflurl =~ /\.(\w+)$/;
 				  my $filezip=$dummypairs[-1];
 				  my $tmp_dir=$ENV{MOBILE_HOME};
 				  $filezip="$tmp_dir/$filezip";
-				  if ($ext_zip eq 'zip') {
-					  if (open(FH, ">$filezip")) {
-						  print FH $content;
-					  close FH;
-					  } else {
-					      ModPerl::Util::exit();
-					      printLog("Error open file:$filezip");
-					  }
-				  } else {
-					  printLog ("The file compress you try to download it's not a zip format");
-					  ModPerl::Util::exit();
-				  }
+				  my $status = getstore ($downloadwurflurl,$filezip);
 				  my $output="$tmp_dir/tmp_wurfl.xml";
 				  unzip $filezip => $output 
 						or die "unzip failed: $UnzipError\n";
@@ -207,6 +192,8 @@ sub loadConfigFile {
 					     ModPerl::Util::exit();
 					}
 			} else {
+				printLog("The file is a xml file.");
+			    my $content = get ($downloadwurflurl);
 				my @rows = split(/\n/, $content);
 				my $row;
 				my $count=0;
@@ -214,6 +201,8 @@ sub loadConfigFile {
 					$r_id=parseWURFLFile($row,$r_id);
 				}
 			}
+			printLog("Finish downloading WURFL from $downloadwurflurl");
+
 	    } else {
 			if (-e "$fileWurfl") {
 					printLog("Start loading  WURFL.xml");
@@ -238,7 +227,15 @@ sub loadConfigFile {
 		#
 		if ($loadwebpatch eq 'true') {
 			if ($patchwurflnetdownload eq "true") {
-				printLog("Start downloading patch WURFL.xml from $patchwurflurl");
+				printLog("Start downloading patch WURFL from $patchwurflurl");
+			    my ($content_type, $document_length, $modified_time, $expires, $server) = head($patchwurflurl);
+		        if ($content_type eq "") {
+	   		        printLog("Couldn't get $patchwurflurl.");
+			   		ModPerl::Util::exit();
+		        } else {
+		            printLog("The URL for download patch WURFL is correct");
+		            printLog("The size of document is: $document_length bytes");	       
+		        }
 				my $content = get ($patchwurflurl);
 				printLog("Finish downloading  WURFL.xml");
 				if ($content eq "") {
@@ -278,7 +275,8 @@ sub loadConfigFile {
 		     printLog("Control also if the file is compress file, and DownloadZipFile parameter is seted false");
 		     ModPerl::Util::exit();
 		}
-        printLog("This version of WURFL have $arrLen UserAgent");
+        printLog("WURFL version: $WURFLVersion");
+        printLog("This version of WURFL has $arrLen UserAgent");
         printLog("End loading  WURFL.xml");
 }
 sub parseWURFLFile {
@@ -329,6 +327,9 @@ sub parseWURFLFile {
 			   $Array_DDRcapability{"$val|$name"}=$value;
 			}
 		 }
+		 if ($record =~ /\<ver/o) {
+		     $WURFLVersion=extValueTag("ver",$record);
+		 }
 		 return $id;
 
 }
@@ -524,23 +525,23 @@ sub handler {
       my $var;
       
       ## uncomment this code for pass the useragent in query string (JUST for demo)
-	  #if ($query_string) {
-	  #		  my @vars = split(/&/, $query_string); 	  
-	  #		  foreach $var (sort @vars){
-	  #				   if ($var) {
-	  #						my ($v,$i) = split(/=/, $var);
-	  #						$v =~ tr/+/ /;
-	  #						$v =~ s/%([a-fA-F0-9][a-fA-F0-9])/pack("C", hex($1))/eg;
-	  #						$i =~ tr/+/ /;
-	  #						$i =~ s/%([a-fA-F0-9][a-fA-F0-9])/pack("C", hex($1))/eg;
-	  #						$i =~ s/<!--(.|\n)*-->//g;
-	  #						$ArrayQuery{$v}=$i;
-	  #					}
-	  #		  }
-	  # }
-	  #	  if ($ArrayQuery{amf}) {
-	  #				$user_agent=$ArrayQuery{amf};
-	  #	  }
+	  if ($query_string) {
+	  		  my @vars = split(/&/, $query_string); 	  
+	  		  foreach $var (sort @vars){
+	  				   if ($var) {
+	  						my ($v,$i) = split(/=/, $var);
+	  					$v =~ tr/+/ /;
+	  					$v =~ s/%([a-fA-F0-9][a-fA-F0-9])/pack("C", hex($1))/eg;
+	  						$i =~ tr/+/ /;
+	  						$i =~ s/%([a-fA-F0-9][a-fA-F0-9])/pack("C", hex($1))/eg;
+	  						$i =~ s/<!--(.|\n)*-->//g;
+	  						$ArrayQuery{$v}=$i;
+	  					}
+	  		  }
+	   }
+	  	  if ($ArrayQuery{amf}) {
+	  				$user_agent=$ArrayQuery{amf};
+	  	  }
 		  
 	
 	
@@ -671,48 +672,60 @@ sub handler {
 					   }
 		} else {
 		 $f->subprocess_env("AMF_VER" => $VERSION);
+		 $f->subprocess_env("AMF_WURFLVER" => $WURFLVersion);
+		 
 		 $return_value=Apache2::Const::DECLINED;
 		}
 
     return $return_value;
 
 }
-
-
-  1; 
+1; 
+__END__
+	
 =head1 NAME
 
 Apache2::WURFLFilter - The module detects the mobile device and passes the WURFL capabilities on to the other web application as environment variables
 
+=head1 SYNOPSYS
 
-=head1 COREQUISITES
+The configuration of V2.x of B<"Apache Mobile Filter"> is very simple thane V1.x, I have deprecated the intelliswitch method because I think that the filter is faster.
 
-CGI
-Apache2
+Add this parameter into httpd.conf file:
 
-=head1 SYNOPSIS
-The configuration of V2.x of "Apache Mobile Filter" is very simple thane V1.x, I have deprecated the intelliswitch method because I think that the filter is faster.
+=over 4
 
-Add this parameter into httpd.conf file
+=item C<PerlSetEnv CapabilityList max_image_width,j2me_midp_2_0> *
 
-PerlSetEnv CapabilityList max_image_width,j2me_midp_2_0 *
-PerlSetEnv MobileVersionUrl /cgi-bin/perl.html ** (default is "none" that mean the filter pass through)
-PerlSetEnv FullBrowserUrl http://www.google.com ** (default is "none" that mean the filter pass through)
-PerlSetEnv WurflNetDownload true***
-PerlSetEnv DownloadWurflURL http://downloads.sourceforge.net/wurfl/wurfl-latest.zip****
-PerlSetEnv DownloadZipFile false
-PerlSetEnv ResizeImageDirectory /transform
-PerlSetEnv Log4WurflNoDeviceDetect /apache2_dev/WurflLog/DeviceNotFound.log
-PerlSetEnv LoadWebPatch true
-PerlSetEnv DirWebPatch /apache2_dev/Apache2/web_browsers_patch.xml   
-PerlSetEnv PatchWurflNetDownload true
-PerlSetEnv PatchWurflUrl http://wurfl.sourceforge.net/web_browsers_patch.xml
-PerlSetEnv RedirectTranscoder true
-PerlSetEnv RedirectTranscoderUrl /transcoderpage.html (default is "none" that mean the filter pass through)
-PerlSetEnv CookieCacheSystem true (default is false, but for production mode is suggested to set in true) 
+=item C<PerlSetEnv MobileVersionUrl /cgi-bin/perl.html> ** (default is "none" that mean the filter pass through)
 
-PerlModule Apache2::WURFLFilter
-PerlTransHandler +Apache2::WURFLFilter
+=item C<PerlSetEnv FullBrowserUrl http://www.google.com> ** (default is "none" that mean the filter pass through)
+
+=item C<PerlSetEnv WurflNetDownload true>***
+
+=item C<PerlSetEnv DownloadWurflURL http://downloads.sourceforge.net/wurfl/wurfl-latest.zip>****
+
+=item C<PerlSetEnv DownloadZipFile false>
+
+=item C<PerlSetEnv ResizeImageDirectory /transform>
+
+=item C<PerlSetEnv LoadWebPatch true>
+
+=item C<PerlSetEnv PatchWurflNetDownload true>
+
+=item C<PerlSetEnv PatchWurflUrl http://wurfl.sourceforge.net/web_browsers_patch.xml>
+
+=item C<PerlSetEnv RedirectTranscoder true>
+
+=item C<PerlSetEnv RedirectTranscoderUrl /transcoderpage.html> (default is "none" that mean the filter pass through)
+
+=item C<PerlSetEnv CookieCacheSystem true> (default is false, but for production mode is suggested to set in true) 
+
+=item C<PerlModule Apache2::WURFLFilter>
+
+=item C<PerlTransHandler +Apache2::WURFLFilter>
+
+=back
 
 * the field separator of each capability you want to consider in your mobile site is ",". Important you now can set ALL (default value) if you want that the filter managed all wurfl capabilities
 
@@ -724,43 +737,59 @@ PerlTransHandler +Apache2::WURFLFilter
 
 ****if you put to true value you can detect a little bit more device, but for strange UA the method take  a lot of time 
 
- 
+
+=head1 DESCRIPTION
 
 For this configuration you need to set this parameter
-=over 4
 
-=item * ConvertImage (boolean): activate/deactivate the adaptation of images to the device
-=item * ResizeImageDirectory: where the new images are saved for cache system, remember this directory must be into docroot directory and also must be writeble from the server
-=item * WurflNetDownload (boolean): if you want to download WURFL xml directly from WURFL site or from an intranet URL (good to have only single point of Wurfl access), default is set to false
-=item * DownloadZipFile (boolean): if you want to download a zip file of WURFL
-=item * DownloadWurflURL: the url of WURFL DB to download**
-=item * CapabilityList/capability : is the capability value you want to pass to you site
-=item * MobileVersionUrl: is the URL address of mobile version site *
-=item * FullBrowserUrl: is the URL address of PC version site *
-=item * RedirectTranscoderURL: the URL where you want to redirect the transcoder*
-=item * ConvertOnlyImages (boolean): if you want to use the filter only for the images and not for other content
-=item * Log4WurflNoDeviceDetect: it's a necessary log for detect new device that WURFL not has included
-=item * LoadWebPatch (boolean): if you want to use a wurfl patch file
-=item * DirWebPatch: set it for indicate where is the patch file on your server
-=item * PatchWurflNetDownload(boolean): if you want download the patch file
-=item * PatchWurflUrl: the URL of the patch file (is readed ony if PatchWurflNet is setted with true)
-=item * DetectAccuracy: if you want to detect with more precision the devices (default is false), I suggest if it's not necessary to leave at false 
+=over 4	
+
+=item C<ConvertImage> (boolean): activate/deactivate the adaptation of images to the device
+
+=item C<ResizeImageDirectory>: where the new images are saved for cache system, remember this directory must be into docroot directory and also must be writeble from the server
+
+=item C<WurflNetDownload> (boolean): if you want to download WURFL xml directly from WURFL site or from an intranet URL (good to have only single point of Wurfl access), default is set to false
+
+=item C<DownloadWurflURL>: the url of WURFL DB to download**
+
+=item C<CapabilityList> : is the capability value you want to pass to you site
+
+=item C<MobileVersionUrl>: is the URL address of mobile version site *
+
+=item C<FullBrowserUrl>: is the URL address of PC version site *
+
+=item C<RedirectTranscoderURL>: the URL where you want to redirect the transcoder*
+
+=item C<ConvertOnlyImages> (boolean): if you want to use the filter only for the images and not for other content
+
+=item C<Log4WurflNoDeviceDetect>: it's a necessary log for detect new device that WURFL not has included
+
+=item C<LoadWebPatch> (boolean): if you want to use a wurfl patch file
+
+=item C<PatchWurflNetDownload>(boolean): if you want download the patch file
+
+=item C<PatchWurflUrl>: the URL of the patch file (is readed ony if PatchWurflNet is setted with true)
+
+=item C<DetectAccuracy>: if you want to detect with more precision the devices (default is false), I suggest if it's not necessary to leave at false 
 
 =back
 
-
 *if you put a relative url (for example "/path") the filter done an internal redirect, if you put a url redirect with protocol (for example "http:") the filter done a classic redirect. If the parameter is not set the filter is a passthrough 
 
 **if you want to download directly the last version of WURFL.xml you can set the url parameter to http://downloads.sourceforge.net/wurfl/wurfl-latest.zip
 
 *** for more info about transcoder problem go to http://wurfl.sourceforge.net
 
-=head1 DOCUMENTATION & DEMO
+=head1 SEE ALSO
 
 For more details: http://www.idelfuschini.it/apache-mobile-filter-v2x.html
 
+Mobile Demo page of the filter: http://apachemobilefilter.nogoogle.it (thanks Ivan alias sigmund)
+
 Demo page of the filter: http://apachemobilefilter.nogoogle.it/php_test.php (thanks Ivan alias sigmund)
 
 =head1 AUTHOR
-Idel Fuschini (idel.fuschini [at] gmail [dot] com
+
+Idel Fuschini (idel.fuschini [at] gmail [dot] com)
+
 =cut
